@@ -1,9 +1,14 @@
-#!/usr/bin/env python3 -u
 # -*- coding: utf-8 -*-
+"""Compositions for classifiers."""
 # copyright: sktime developers, BSD-3-Clause License (see LICENSE file)
 
-__author__ = ["Markus Löning"]
-__all__ = ["ComposableTimeSeriesForestClassifier", "ColumnEnsembleClassifier"]
+__author__ = ["mloning", "fkiraly"]
+__all__ = [
+    "ClassifierPipeline",
+    "ComposableTimeSeriesForestClassifier",
+    "ColumnEnsembleClassifier",
+]
 
 from sktime.classification.compose._column_ensemble import ColumnEnsembleClassifier
 from sktime.classification.compose._ensemble import ComposableTimeSeriesForestClassifier
+from sktime.classification.compose._pipeline import ClassifierPipeline
