@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 """BOSS classifiers.
 
-dictionary based BOSS classifiers based on SFA transform. Contains a single
+Dictionary based BOSS classifiers based on SFA transform. Contains a single
 BOSS and a BOSS ensemble.
 """
 
-__author__ = "Matthew Middlehurst"
+__author__ = ["MatthewMiddlehurst"]
 __all__ = ["BOSSEnsemble", "IndividualBOSS", "boss_distance"]
 
 import sys
@@ -13,12 +13,13 @@ from itertools import compress
 
 import numpy as np
 from joblib import Parallel, delayed
+from numba import njit, types
+from numba.typed.typeddict import Dict
 from sklearn.utils import check_random_state
-from sklearn.utils.multiclass import class_distribution
 
 from sktime.classification.base import BaseClassifier
 from sktime.transformations.panel.dictionary_based import SFA
-from sktime.utils.validation.panel import check_X, check_X_y
+from sktime.utils.validation.panel import check_X_y
 
 
 class BOSSEnsemble(BaseClassifier):
@@ -57,6 +58,14 @@ class BOSSEnsemble(BaseClassifier):
         Maximum window length as a proportion of the series length.
     min_window : int, default=10
         Minimum window size.
+    typed_dict : bool, default=True
+        Use a numba TypedDict to store word counts. May increase memory usage, but will
+        be faster for larger datasets. As the Dict cannot be pickled currently, there
+        will be some overhead converting it to a python dict with multiple threads and
+        pickling.
+    save_train_predictions : bool, default=False
+        Save the ensemble member train predictions in fit for use in _get_train_probs
+        leave-one-out cross-validation.
     n_jobs : int, default=1
         The number of jobs to run in parallel for both `fit` and `predict`.
         ``-1`` means using all processors.
@@ -65,20 +74,19 @@ class BOSSEnsemble(BaseClassifier):
 
     Attributes
     ----------
-    n_classes : int
+    n_classes_ : int
         Number of classes. Extracted from the data.
-    n_instances : int
+    classes_ : list
+        The classes labels.
+    n_instances_ : int
         Number of instances. Extracted from the data.
-    n_estimators : int
+    n_estimators_ : int
         The final number of classifiers used. Will be <= `max_ensemble_size` if
         `max_ensemble_size` has been specified.
-    series_length : int
+    series_length_ : int
         Length of all series (assumed equal).
-    classifiers : list
+    estimators_ : list
        List of DecisionTree classifiers.
-    class_dictionary: dict
-        Dictionary of classes. Extracted from the data.
-
 
     See Also
     --------
@@ -99,22 +107,19 @@ class BOSSEnsemble(BaseClassifier):
     Examples
     --------
     >>> from sktime.classification.dictionary_based import BOSSEnsemble
-    >>> from sktime.datasets import load_italy_power_demand
-    >>> X_train, y_train = load_italy_power_demand(split="train", return_X_y=True)
-    >>> X_test, y_test = load_italy_power_demand(split="test", return_X_y=True)
-    >>> clf = BOSSEnsemble()
+    >>> from sktime.datasets import load_unit_test
+    >>> X_train, y_train = load_unit_test(split="train", return_X_y=True)
+    >>> X_test, y_test = load_unit_test(split="test", return_X_y=True)
+    >>> clf = BOSSEnsemble(max_ensemble_size=5)
     >>> clf.fit(X_train, y_train)
     BOSSEnsemble(...)
     >>> y_pred = clf.predict(X_test)
     """
 
-    # Capability tags
-    capabilities = {
-        "multivariate": False,
-        "unequal_length": False,
-        "missing_values": False,
-        "train_estimate": True,
-        "contractable": False,
+    _tags = {
+        "capability:train_estimate": True,
+        "capability:multithreading": True,
+        "classifier_type": "dictionary",
     }
 
     def __init__(
@@ -123,31 +128,33 @@ class BOSSEnsemble(BaseClassifier):
         max_ensemble_size=500,
         max_win_len_prop=1,
         min_window=10,
+        typed_dict=True,
+        save_train_predictions=False,
         n_jobs=1,
         random_state=None,
     ):
         self.threshold = threshold
         self.max_ensemble_size = max_ensemble_size
         self.max_win_len_prop = max_win_len_prop
+        self.min_window = min_window
 
+        self.typed_dict = typed_dict
+        self.save_train_predictions = save_train_predictions
         self.n_jobs = n_jobs
         self.random_state = random_state
 
-        self.classifiers = []
-        self.n_classes = 0
-        self.classes_ = []
-        self.class_dictionary = {}
-        self.n_estimators = 0
-        self.series_length = 0
-        self.n_instances = 0
+        self.estimators_ = []
+        self.n_estimators_ = 0
+        self.series_length_ = 0
+        self.n_instances_ = 0
+
+        self._word_lengths = [16, 14, 12, 10, 8]
+        self._norm_options = [True, False]
+        self._alphabet_size = 4
 
-        self.word_lengths = [16, 14, 12, 10, 8]
-        self.norm_options = [True, False]
-        self.min_window = min_window
-        self.alphabet_size = 4
         super(BOSSEnsemble, self).__init__()
 
-    def fit(self, X, y):
+    def _fit(self, X, y):
         """Fit a boss ensemble on cases (X,y), where y is the target variable.
 
         Build an ensemble of BOSS classifiers from the training set (X,
@@ -156,28 +163,29 @@ class BOSSEnsemble(BaseClassifier):
 
         Parameters
         ----------
-        X : pd.DataFrame of shape [n_instances, 1]
-            Nested dataframe with univariate time-series in cells.
-        y : array-like, shape = [n_instances] The class labels.
+        X : 3D np.array of shape = [n_instances, n_dimensions, series_length]
+            The training data.
+        y : array-like, shape = [n_instances]
+            The class labels.
 
         Returns
         -------
-        self : object
+        self :
+            Reference to self.
+
+        Notes
+        -----
+        Changes state by creating a fitted model that updates attributes
+        ending in "_" and sets is_fitted flag to True.
         """
-        X, y = check_X_y(X, y, enforce_univariate=True, coerce_to_numpy=True)
+        self.n_instances_, _, self.series_length_ = X.shape
 
-        self.n_instances, _, self.series_length = X.shape
-        self.n_classes = np.unique(y).shape[0]
-        self.classes_ = class_distribution(np.asarray(y).reshape(-1, 1))[0][0]
-        for index, classVal in enumerate(self.classes_):
-            self.class_dictionary[classVal] = index
-
-        self.classifiers = []
+        self.estimators_ = []
 
         # Window length parameter space dependent on series length
-        max_window_searches = self.series_length / 4
+        max_window_searches = self.series_length_ / 4
 
-        max_window = int(self.series_length * self.max_win_len_prop)
+        max_window = int(self.series_length_ * self.max_win_len_prop)
         win_inc = int((max_window - self.min_window) / max_window_searches)
         if win_inc < 1:
             win_inc = 1
@@ -185,22 +193,23 @@ class BOSSEnsemble(BaseClassifier):
             raise ValueError(
                 f"Error in BOSSEnsemble, min_window ="
                 f"{self.min_window} is bigger"
-                f" than max_window ={max_window},"
-                f" series length is {self.series_length}"
-                f" try set min_window to be smaller than series length in "
+                f" than max_window ={max_window}."
+                f" Try set min_window to be smaller than series length in "
                 f"the constructor, but the classifier may not work at "
                 f"all with very short series"
             )
         max_acc = -1
         min_max_acc = -1
-        for normalise in self.norm_options:
+        for normalise in self._norm_options:
             for win_size in range(self.min_window, max_window + 1, win_inc):
                 boss = IndividualBOSS(
                     win_size,
-                    self.word_lengths[0],
+                    self._word_lengths[0],
                     normalise,
-                    self.alphabet_size,
+                    self._alphabet_size,
                     save_words=True,
+                    typed_dict=self.typed_dict,
+                    n_jobs=self._threads_to_use,
                     random_state=self.random_state,
                 )
                 boss.fit(X, y)
@@ -209,18 +218,18 @@ class BOSSEnsemble(BaseClassifier):
                 best_acc_for_win_size = -1
 
                 # the used word length may be shorter
-                best_word_len = boss.transformer.word_length
+                best_word_len = boss._transformer.word_length
 
-                for n, word_len in enumerate(self.word_lengths):
+                for n, word_len in enumerate(self._word_lengths):
                     if n > 0:
                         boss = boss._shorten_bags(word_len)
 
-                    boss.accuracy = self._individual_train_acc(
-                        boss, y, self.n_instances, best_acc_for_win_size
+                    boss._accuracy = self._individual_train_acc(
+                        boss, y, self.n_instances_, best_acc_for_win_size
                     )
 
-                    if boss.accuracy >= best_acc_for_win_size:
-                        best_acc_for_win_size = boss.accuracy
+                    if boss._accuracy >= best_acc_for_win_size:
+                        best_acc_for_win_size = boss._accuracy
                         best_classifier_for_win_size = boss
                         best_word_len = word_len
 
@@ -228,47 +237,47 @@ class BOSSEnsemble(BaseClassifier):
                     best_acc_for_win_size,
                     max_acc,
                     min_max_acc,
-                    len(self.classifiers),
+                    len(self.estimators_),
                 ):
                     best_classifier_for_win_size._clean()
                     best_classifier_for_win_size._set_word_len(best_word_len)
-                    self.classifiers.append(best_classifier_for_win_size)
+                    self.estimators_.append(best_classifier_for_win_size)
 
                     if best_acc_for_win_size > max_acc:
                         max_acc = best_acc_for_win_size
-                        self.classifiers = list(
+                        self.estimators_ = list(
                             compress(
-                                self.classifiers,
+                                self.estimators_,
                                 [
-                                    classifier.accuracy >= max_acc * self.threshold
-                                    for c, classifier in enumerate(self.classifiers)
+                                    classifier._accuracy >= max_acc * self.threshold
+                                    for c, classifier in enumerate(self.estimators_)
                                 ],
                             )
                         )
 
                     min_max_acc, min_acc_ind = self._worst_ensemble_acc()
 
-                    if len(self.classifiers) > self.max_ensemble_size:
+                    if len(self.estimators_) > self.max_ensemble_size:
                         if min_acc_ind > -1:
-                            del self.classifiers[min_acc_ind]
+                            del self.estimators_[min_acc_ind]
                             min_max_acc, min_acc_ind = self._worst_ensemble_acc()
 
-        self.n_estimators = len(self.classifiers)
+        self.n_estimators_ = len(self.estimators_)
 
-        self._is_fitted = True
         return self
 
-    def predict(self, X):
+    def _predict(self, X) -> np.ndarray:
         """Predict class values of n instances in X.
 
         Parameters
         ----------
-        X : pd.DataFrame of shape (n_instances, 1)
+        X : 3D np.array of shape = [n_instances, n_dimensions, series_length]
+            The data to make predictions for.
 
         Returns
         -------
-        preds : np.ndarray of shape (n, 1)
-            Predicted class.
+        y : array-like, shape = [n_instances]
+            Predicted class labels.
         """
         rng = check_random_state(self.random_state)
         return np.array(
@@ -278,28 +287,26 @@ class BOSSEnsemble(BaseClassifier):
             ]
         )
 
-    def predict_proba(self, X):
+    def _predict_proba(self, X) -> np.ndarray:
         """Predict class probabilities for n instances in X.
 
         Parameters
         ----------
-        X : pd.DataFrame of shape (n_instances, 1)
+        X : 3D np.array of shape = [n_instances, n_dimensions, series_length]
+            The data to make predict probabilities for.
 
         Returns
         -------
-        dists : array of shape (n_instances, n_classes)
-            Predicted probability of each class.
+        y : array-like, shape = [n_instances, n_classes_]
+            Predicted probabilities using the ordering in classes_.
         """
-        self.check_is_fitted()
-        X = check_X(X, enforce_univariate=True, coerce_to_numpy=True)
+        sums = np.zeros((X.shape[0], self.n_classes_))
 
-        sums = np.zeros((X.shape[0], self.n_classes))
-
-        for clf in self.classifiers:
+        for clf in self.estimators_:
             preds = clf.predict(X)
             for i in range(0, X.shape[0]):
-                sums[i, self.class_dictionary[preds[i]]] += 1
-        dists = sums / (np.ones(self.n_classes) * self.n_estimators)
+                sums[i, self._class_dictionary[preds[i]]] += 1
+        dists = sums / (np.ones(self.n_classes_) * self.n_estimators_)
 
         return dists
 
@@ -315,33 +322,51 @@ class BOSSEnsemble(BaseClassifier):
         min_acc = 1.0
         min_acc_idx = -1
 
-        for c, classifier in enumerate(self.classifiers):
-            if classifier.accuracy < min_acc:
-                min_acc = classifier.accuracy
+        for c, classifier in enumerate(self.estimators_):
+            if classifier._accuracy < min_acc:
+                min_acc = classifier._accuracy
                 min_acc_idx = c
 
         return min_acc, min_acc_idx
 
-    def _get_train_probs(self, X):
-        num_inst = X.shape[0]
-        results = np.zeros((num_inst, self.n_classes))
-        divisor = np.ones(self.n_classes) * self.n_estimators
-        for i in range(num_inst):
-            sums = np.zeros(self.n_classes)
+    def _get_train_probs(self, X, y):
+        self.check_is_fitted()
+        X, y = check_X_y(X, y, coerce_to_numpy=True, enforce_univariate=True)
 
-            preds = Parallel(n_jobs=self.n_jobs)(
-                delayed(clf._train_predict)(
-                    i,
-                )
-                for clf in self.classifiers
+        n_instances, _, series_length = X.shape
+
+        if n_instances != self.n_instances_ or series_length != self.series_length_:
+            raise ValueError(
+                "n_instances, series_length mismatch. X should be "
+                "the same as the training data used in fit for generating train "
+                "probabilities."
             )
 
-            for c in preds:
-                sums[self.class_dictionary.get(c, -1)] += 1
+        results = np.zeros((n_instances, self.n_classes_))
+        divisors = np.zeros(n_instances)
 
-            dists = sums / divisor
-            for n in range(self.n_classes):
-                results[i][n] = dists[n]
+        for i, clf in enumerate(self.estimators_):
+            preds = (
+                clf._train_predictions
+                if self.save_train_predictions
+                else Parallel(n_jobs=self._threads_to_use)(
+                    delayed(clf._train_predict)(
+                        i,
+                    )
+                    for i in range(n_instances)
+                )
+            )
+
+            for n, pred in enumerate(preds):
+                results[n][self._class_dictionary[pred]] += 1
+                divisors[n] += 1
+
+        for i in range(n_instances):
+            results[i] = (
+                np.ones(self.n_classes_) * (1 / self.n_classes_)
+                if divisors[i] == 0
+                else results[i] / (np.ones(self.n_classes_) * divisors[i])
+            )
 
         return results
 
@@ -349,8 +374,8 @@ class BOSSEnsemble(BaseClassifier):
         correct = 0
         required_correct = int(lowest_acc * train_size)
 
-        if self.n_jobs > 1:
-            c = Parallel(n_jobs=self.n_jobs)(
+        if self._threads_to_use > 1:
+            c = Parallel(n_jobs=self._threads_to_use)(
                 delayed(boss._train_predict)(
                     i,
                 )
@@ -362,6 +387,9 @@ class BOSSEnsemble(BaseClassifier):
                     return -1
                 elif c[i] == y[i]:
                     correct += 1
+
+                if self.save_train_predictions:
+                    boss._train_predictions.append(c[i])
         else:
             for i in range(train_size):
                 if correct + train_size - i < required_correct:
@@ -372,8 +400,26 @@ class BOSSEnsemble(BaseClassifier):
                 if c == y[i]:
                     correct += 1
 
+                if self.save_train_predictions:
+                    boss._train_predictions.append(c)
+
         return correct / train_size
 
+    @classmethod
+    def get_test_params(cls):
+        """Return testing parameter settings for the estimator.
+
+        Returns
+        -------
+        params : dict or list of dict, default={}
+            Parameters to create testing instances of the class.
+            Each dict are parameters to construct an "interesting" test instance, i.e.,
+            `MyClass(**params)` or `MyClass(**params[i])` creates a valid test instance.
+            `create_test_instance` uses the first (or only) dictionary in `params`.
+        """
+        params = {"max_ensemble_size": 2}
+        return params
+
 
 class IndividualBOSS(BaseClassifier):
     """Single bag of Symbolic Fourier Approximation Symbols (IndividualBOSS).
@@ -408,6 +454,9 @@ class IndividualBOSS(BaseClassifier):
         the dictionary of words is returned. If True, the array is saved, which
         can shorten the time to calculate dictionaries using a shorter
         `word_length` (since the last "n" letters can be removed).
+    typed_dict : bool, default=True
+        Use a numba TypedDict to store word counts. May increase memory usage, but will
+        be faster for larger datasets.
     n_jobs : int, default=1
         The number of jobs to run in parallel for both `fit` and `predict`.
         ``-1`` means using all processors.
@@ -416,17 +465,10 @@ class IndividualBOSS(BaseClassifier):
 
     Attributes
     ----------
-    n_classes : int
+    n_classes_ : int
         Number of classes. Extracted from the data.
-    n_instances : int
-        Number of instances. Extracted from the data.
-    n_estimators : int
-        The final number of classifiers used. Will be <= `max_ensemble_size` if
-        `max_ensemble_size` has been specified.
-    series_length : int
-        Length of all series (assumed equal).
-    class_dictionary: dict
-        Dictionary of classes. Extracted from the data.
+    classes_ : list
+        The classes labels.
 
     See Also
     --------
@@ -436,7 +478,7 @@ class IndividualBOSS(BaseClassifier):
     -----
     For the Java version, see
     `TSML <https://github.com/uea-machine-learning/tsml/blob/master/src/main/java/
-    tsml/classifiers/dictionary_based/BOSS.java>`_.
+    tsml/classifiers/dictionary_based/IndividualBOSS.java>`_.
 
     References
     ----------
@@ -447,22 +489,27 @@ class IndividualBOSS(BaseClassifier):
     Examples
     --------
     >>> from sktime.classification.dictionary_based import IndividualBOSS
-    >>> from sktime.datasets import load_italy_power_demand
-    >>> X_train, y_train = load_italy_power_demand(split="train", return_X_y=True)
-    >>> X_test, y_test = load_italy_power_demand(split="test", return_X_y=True)
+    >>> from sktime.datasets import load_unit_test
+    >>> X_train, y_train = load_unit_test(split="train", return_X_y=True)
+    >>> X_test, y_test = load_unit_test(split="test", return_X_y=True)
     >>> clf = IndividualBOSS()
     >>> clf.fit(X_train, y_train)
     IndividualBOSS(...)
     >>> y_pred = clf.predict(X_test)
     """
 
+    _tags = {
+        "capability:multithreading": True,
+    }
+
     def __init__(
         self,
         window_size=10,
         word_length=8,
         norm=False,
         alphabet_size=4,
-        save_words=True,
+        save_words=False,
+        typed_dict=True,
         n_jobs=1,
         random_state=None,
     ):
@@ -472,74 +519,99 @@ class IndividualBOSS(BaseClassifier):
         self.alphabet_size = alphabet_size
 
         self.save_words = save_words
+        self.typed_dict = typed_dict
         self.n_jobs = n_jobs
         self.random_state = random_state
 
-        self.transformer = SFA(
-            word_length=word_length,
-            alphabet_size=alphabet_size,
-            window_size=window_size,
-            norm=norm,
-            remove_repeat_words=True,
-            bigrams=False,
-            save_words=save_words,
-            n_jobs=n_jobs,
-        )
-        self.transformed_data = []
-        self.accuracy = 0
-        self.subsample = []
+        self._transformer = None
+        self._transformed_data = []
+        self._class_vals = []
+        self._accuracy = 0
+        self._subsample = []
+        self._train_predictions = []
 
-        self.class_vals = []
-        self.num_classes = 0
-        self.classes_ = []
-        self.class_dictionary = {}
         super(IndividualBOSS, self).__init__()
 
-    def fit(self, X, y):
+    def __getstate__(self):
+        """Return state as dictionary for pickling, required for typed Dict objects."""
+        state = self.__dict__.copy()
+        if self.typed_dict:
+            nl = [None] * len(self._transformed_data)
+            for i, ndict in enumerate(state["_transformed_data"]):
+                pdict = dict()
+                for key, val in ndict.items():
+                    pdict[key] = val
+                nl[i] = pdict
+            state["_transformed_data"] = nl
+        return state
+
+    def __setstate__(self, state):
+        """Set current state using input pickling, required for typed Dict objects."""
+        self.__dict__.update(state)
+        if self.typed_dict:
+            nl = [None] * len(self._transformed_data)
+            for i, pdict in enumerate(self._transformed_data):
+                ndict = Dict.empty(key_type=types.int64, value_type=types.uint32)
+                for key, val in pdict.items():
+                    ndict[key] = val
+                nl[i] = ndict
+            self._transformed_data = nl
+
+    def _fit(self, X, y):
         """Fit a single boss classifier on n_instances cases (X,y).
 
         Parameters
         ----------
-        X : pd.DataFrame of shape [n_instances, 1]
-            Nested dataframe with univariate time-series in cells.
-        y : array-like, shape = [n_instances] The class labels.
+        X : 3D np.array of shape = [n_instances, n_dimensions, series_length]
+            The training data.
+        y : array-like, shape = [n_instances]
+            The class labels.
 
         Returns
         -------
-        self : object
+        self :
+            Reference to self.
+
+        Notes
+        -----
+        Changes state by creating a fitted model that updates attributes
+        ending in "_" and sets is_fitted flag to True.
         """
-        X, y = check_X_y(X, y, enforce_univariate=True, coerce_to_numpy=True)
+        self._transformer = SFA(
+            word_length=self.word_length,
+            alphabet_size=self.alphabet_size,
+            window_size=self.window_size,
+            norm=self.norm,
+            remove_repeat_words=True,
+            bigrams=False,
+            save_words=self.save_words,
+            typed_dict=self.typed_dict,
+            n_jobs=self._threads_to_use,
+        )
 
-        sfa = self.transformer.fit_transform(X)
-        self.transformed_data = sfa[0]
+        sfa = self._transformer.fit_transform(X)
+        self._transformed_data = sfa[0]
+        self._class_vals = y
 
-        self.class_vals = y
-        self.num_classes = np.unique(y).shape[0]
-        self.classes_ = class_distribution(np.asarray(y).reshape(-1, 1))[0][0]
-        for index, classVal in enumerate(self.classes_):
-            self.class_dictionary[classVal] = index
-
-        self._is_fitted = True
         return self
 
-    def predict(self, X):
+    def _predict(self, X):
         """Predict class values of all instances in X.
 
         Parameters
         ----------
-        X : pd.DataFrame of shape [n, 1]
+        X : 3D np.array of shape = [n_instances, n_dimensions, series_length]
+            The data to make predictions for.
 
         Returns
         -------
-        array of shape [n, 1]
+        y : array-like, shape = [n_instances]
+            Predicted class labels.
         """
-        self.check_is_fitted()
-        X = check_X(X, enforce_univariate=True, coerce_to_numpy=True)
-
-        test_bags = self.transformer.transform(X)
+        test_bags = self._transformer.transform(X)
         test_bags = test_bags[0]
 
-        classes = Parallel(n_jobs=self.n_jobs)(
+        classes = Parallel(n_jobs=self._threads_to_use)(
             delayed(self._test_nn)(
                 test_bag,
             )
@@ -548,46 +620,27 @@ class IndividualBOSS(BaseClassifier):
 
         return np.array(classes)
 
-    def predict_proba(self, X):
-        """Predict class probabilities for all instances in X.
-
-        Parameters
-        ----------
-        X : pd.DataFrame of shape [n, 1]
-
-        Returns
-        -------
-        dists : array of shape [n, self.n_classes]
-        """
-        preds = self.predict(X)
-        dists = np.zeros((X.shape[0], self.num_classes))
-
-        for i in range(0, X.shape[0]):
-            dists[i, self.class_dictionary.get(preds[i])] += 1
-
-        return dists
-
     def _test_nn(self, test_bag):
         rng = check_random_state(self.random_state)
 
         best_dist = sys.float_info.max
         nn = None
 
-        for n, bag in enumerate(self.transformed_data):
+        for n, bag in enumerate(self._transformed_data):
             dist = boss_distance(test_bag, bag, best_dist)
 
             if dist < best_dist or (dist == best_dist and rng.random() < 0.5):
                 best_dist = dist
-                nn = self.class_vals[n]
+                nn = self._class_vals[n]
 
         return nn
 
     def _train_predict(self, train_num):
-        test_bag = self.transformed_data[train_num]
+        test_bag = self._transformed_data[train_num]
         best_dist = sys.float_info.max
         nn = None
 
-        for n, bag in enumerate(self.transformed_data):
+        for n, bag in enumerate(self._transformed_data):
             if n == train_num:
                 continue
 
@@ -595,7 +648,7 @@ class IndividualBOSS(BaseClassifier):
 
             if dist < best_dist:
                 best_dist = dist
-                nn = self.class_vals[n]
+                nn = self._class_vals[n]
 
         return nn
 
@@ -606,32 +659,30 @@ class IndividualBOSS(BaseClassifier):
             self.norm,
             self.alphabet_size,
             save_words=self.save_words,
+            typed_dict=self.typed_dict,
             random_state=self.random_state,
+            n_jobs=self.n_jobs,
         )
-        new_boss.transformer = self.transformer
-        sfa = self.transformer._shorten_bags(word_len)
-        new_boss.transformed_data = sfa[0]
+        new_boss._transformer = self._transformer
+        sfa = self._transformer._shorten_bags(word_len)
+        new_boss._transformed_data = sfa[0]
 
-        new_boss.class_vals = self.class_vals
-        new_boss.num_classes = self.num_classes
+        new_boss._class_vals = self._class_vals
+        new_boss.n_classes_ = self.n_classes_
         new_boss.classes_ = self.classes_
-        new_boss.class_dictionary = self.class_dictionary
+        new_boss._class_dictionary = self._class_dictionary
 
+        new_boss._threads_to_use = self._threads_to_use
         new_boss._is_fitted = True
         return new_boss
 
     def _clean(self):
-        self.transformer.words = None
-        self.transformer.save_words = False
+        self._transformer.words = None
+        self._transformer.save_words = False
 
     def _set_word_len(self, word_len):
         self.word_length = word_len
-        self.transformer.word_length = word_len
-
-
-# @njit()
-# def _dist(val_a, val_b):
-#     return (val_a - val_b) * (val_a - val_b)
+        self._transformer.word_length = word_len
 
 
 def boss_distance(first, second, best_dist=sys.float_info.max):
@@ -661,9 +712,8 @@ def boss_distance(first, second, best_dist=sys.float_info.max):
     dist : float
         The boss distance between the first and second dictionaries.
     """
-    dist = 0
-
     if isinstance(first, dict):
+        dist = 0
         for word, val_a in first.items():
             val_b = second.get(word, 0)
             buf = val_a - val_b
@@ -671,12 +721,26 @@ def boss_distance(first, second, best_dist=sys.float_info.max):
 
             if dist > best_dist:
                 return sys.float_info.max
+        return dist
+    elif isinstance(first, Dict):
+        return _boss_distance_dict(first, second, best_dist)
     else:
-        dist = np.sum(
+        return np.sum(
             [
                 0 if first[i] == 0 else (first[i] - second[i]) * (first[i] - second[i])
                 for i in range(len(first))
             ]
         )
 
+
+@njit(fastmath=True, cache=True)
+def _boss_distance_dict(first, second, best_dist):
+    dist = 0
+    for word, val_a in first.items():
+        val_b = second.get(word, types.uint32(0))
+        buf = val_a - val_b
+        dist += buf * buf
+
+        if dist > best_dist:
+            return 0x7FFFFFFFFFFFFFFF
     return dist
