@@ -11,8 +11,8 @@ from sktime.datasets import load_unit_test
 def test_cboss_on_unit_test_data():
     """Test of cBOSS on unit test data."""
     # load unit test data
-    X_train, y_train = load_unit_test(split="train", return_X_y=True)
-    X_test, y_test = load_unit_test(split="test", return_X_y=True)
+    X_train, y_train = load_unit_test(split="train")
+    X_test, y_test = load_unit_test(split="test")
     indices = np.random.RandomState(0).choice(len(y_train), 10, replace=False)
 
     # train cBOSS
@@ -78,28 +78,3 @@ cboss_unit_test_probas = np.array(
         ],
     ]
 )
-
-
-# def print_array(array):
-#     print('[')
-#     for sub_array in array:
-#         print('[')
-#         for value in sub_array:
-#             print(value.astype(str), end='')
-#             print(', ')
-#         print('],')
-#     print(']')
-#
-#
-# if __name__ == "__main__":
-#     X_train, y_train = load_unit_test(split="train", return_X_y=True)
-#     X_test, y_test = load_unit_test(split="test", return_X_y=True)
-#     indices = np.random.RandomState(0).choice(len(y_train), 10, replace=False)
-#
-#     cboss = ContractableBOSS(
-#         n_parameter_samples=25, max_ensemble_size=5, random_state=0
-#     )
-#
-#     cboss.fit(X_train, y_train)
-#     probas = cboss.predict_proba(X_test.iloc[indices])
-#     print_array(probas)
