@@ -13,6 +13,7 @@ import numpy as np
 from joblib import Parallel, delayed
 from sklearn.linear_model import RidgeClassifierCV
 from sklearn.pipeline import make_pipeline
+from sklearn.preprocessing import StandardScaler
 from sklearn.utils import check_random_state
 
 from sktime.base._base import _clone_estimator
@@ -115,6 +116,7 @@ class Arsenal(BaseClassifier):
         "capability:train_estimate": True,
         "capability:contractable": True,
         "capability:multithreading": True,
+        "classifier_type": "kernel",
     }
 
     def __init__(
@@ -175,7 +177,6 @@ class Arsenal(BaseClassifier):
         ending in "_" and sets is_fitted flag to True.
         """
         self.n_instances_, self.n_dims_, self.series_length_ = X.shape
-
         time_limit = self.time_limit_in_minutes * 60
         start_time = time.time()
         train_time = 0
@@ -263,13 +264,13 @@ class Arsenal(BaseClassifier):
         self.weights_ = []
         self._weight_sum = 0
         for rocket_pipeline in self.estimators_:
-            weight = rocket_pipeline.steps[1][1].best_score_
+            weight = rocket_pipeline.steps[2][1].best_score_
             self.weights_.append(weight)
             self._weight_sum += weight
 
         return self
 
-    def _predict(self, X):
+    def _predict(self, X) -> np.ndarray:
         """Predicts labels for sequences in X.
 
         Parameters
@@ -290,7 +291,7 @@ class Arsenal(BaseClassifier):
             ]
         )
 
-    def _predict_proba(self, X):
+    def _predict_proba(self, X) -> np.ndarray:
         """Predicts labels probabilities for sequences in X.
 
         Parameters
@@ -316,7 +317,7 @@ class Arsenal(BaseClassifier):
             np.sum(y_probas, axis=0) / (np.ones(self.n_classes_) * self._weight_sum), 8
         )
 
-    def _get_train_probs(self, X, y):
+    def _get_train_probs(self, X, y) -> np.ndarray:
         self.check_is_fitted()
         X, y = check_X_y(X, y, coerce_to_numpy=True)
 
@@ -343,13 +344,13 @@ class Arsenal(BaseClassifier):
             )
             for i in range(self.n_estimators)
         )
-        y_probas, oobs = zip(*p)
+        y_probas, weights, oobs = zip(*p)
 
         results = np.sum(y_probas, axis=0)
         divisors = np.zeros(n_instances)
         for n, oob in enumerate(oobs):
             for inst in oob:
-                divisors[inst] += self.weights_[n]
+                divisors[inst] += weights[n]
 
         for i in range(n_instances):
             results[i] = (
@@ -362,10 +363,12 @@ class Arsenal(BaseClassifier):
 
     def _fit_estimator(self, rocket, X, y):
         transformed_x = rocket.fit_transform(X)
-        ridge = RidgeClassifierCV(alphas=np.logspace(-3, 3, 10), normalize=True)
-        ridge.fit(transformed_x, y)
+        scaler = StandardScaler(with_mean=False)
+        scaler.fit(transformed_x, y)
+        ridge = RidgeClassifierCV(alphas=np.logspace(-3, 3, 10))
+        ridge.fit(scaler.transform(transformed_x), y)
         return [
-            make_pipeline(rocket, ridge),
+            make_pipeline(rocket, scaler, ridge),
             transformed_x if self.save_transformed_data else None,
         ]
 
@@ -378,19 +381,46 @@ class Arsenal(BaseClassifier):
 
     def _train_probas_for_estimator(self, y, idx):
         rs = 255 if self.random_state == 0 else self.random_state
-        rs = None if self.random_state is None else rs * 37 * (idx + 1)
+        rs = (
+            None
+            if self.random_state is None
+            else (rs * 37 * (idx + 1)) % np.iinfo(np.int32).max
+        )
         rng = check_random_state(rs)
 
         indices = range(self.n_instances_)
         subsample = rng.choice(self.n_instances_, size=self.n_instances_)
         oob = [n for n in indices if n not in subsample]
 
-        clf = RidgeClassifierCV(alphas=np.logspace(-3, 3, 10), normalize=True)
+        results = np.zeros((self.n_instances_, self.n_classes_))
+        if len(oob) == 0:
+            return results, 1, oob
+
+        clf = make_pipeline(
+            StandardScaler(with_mean=False),
+            RidgeClassifierCV(alphas=np.logspace(-3, 3, 10)),
+        )
         clf.fit(self.transformed_data_[idx].iloc[subsample], y[subsample])
         preds = clf.predict(self.transformed_data_[idx].iloc[oob])
 
-        results = np.zeros((self.n_instances_, self.n_classes_))
-        for n, pred in enumerate(preds):
-            results[oob[n]][self._class_dictionary[pred]] += self.weights_[idx]
+        weight = clf.steps[1][1].best_score_
 
-        return results, oob
+        for n, pred in enumerate(preds):
+            results[oob[n]][self._class_dictionary[pred]] += weight
+
+        return results, weight, oob
+
+    @classmethod
+    def get_test_params(cls):
+        """Return testing parameter settings for the estimator.
+
+        Returns
+        -------
+        params : dict or list of dict, default={}
+            Parameters to create testing instances of the class.
+            Each dict are parameters to construct an "interesting" test instance, i.e.,
+            `MyClass(**params)` or `MyClass(**params[i])` creates a valid test instance.
+            `create_test_instance` uses the first (or only) dictionary in `params`.
+        """
+        params = {"num_kernels": 10, "n_estimators": 2}
+        return params
