@@ -34,6 +34,7 @@ __all__ = [
     "load_gun_point_segmentation",
     "load_electric_devices_segmentation",
     "load_macroeconomic",
+    "load_unit_test_tsf",
 ]
 
 import os
@@ -42,7 +43,11 @@ import numpy as np
 import pandas as pd
 import statsmodels.api as sm
 
-from sktime.datasets._data_io import _load_dataset, _load_provided_dataset
+from sktime.datasets._data_io import (
+    _load_dataset,
+    _load_provided_dataset,
+    load_tsf_to_dataframe,
+)
 
 DIRNAME = "data"
 MODULE = os.path.dirname(__file__)
@@ -512,7 +517,7 @@ def load_shampoo_sales():
     name = "ShampooSales"
     fname = name + ".csv"
     path = os.path.join(MODULE, DIRNAME, name, fname)
-    y = pd.read_csv(path, index_col=0, squeeze=True, dtype={1: np.float})
+    y = pd.read_csv(path, index_col=0, squeeze=True, dtype={1: float})
     y.index = pd.PeriodIndex(y.index, freq="M", name="Period")
     y.name = "Number of shampoo sales"
     return y
@@ -566,7 +571,7 @@ def load_longley(y_name="TOTEMP"):
     data = pd.read_csv(path, index_col=0)
     data = data.set_index("YEAR")
     data.index = pd.PeriodIndex(data.index, freq="Y", name="Period")
-    data = data.astype(np.float)
+    data = data.astype(float)
 
     # Get target series
     y = data.pop(y_name)
@@ -613,7 +618,7 @@ def load_lynx():
     name = "Lynx"
     fname = name + ".csv"
     path = os.path.join(MODULE, DIRNAME, name, fname)
-    y = pd.read_csv(path, index_col=0, squeeze=True, dtype={1: np.float})
+    y = pd.read_csv(path, index_col=0, squeeze=True, dtype={1: float})
     y.index = pd.PeriodIndex(y.index, freq="Y", name="Period")
     y.name = "Number of Lynx trappings"
     return y
@@ -650,7 +655,7 @@ def load_airline():
     name = "Airline"
     fname = name + ".csv"
     path = os.path.join(MODULE, DIRNAME, name, fname)
-    y = pd.read_csv(path, index_col=0, squeeze=True, dtype={1: np.float})
+    y = pd.read_csv(path, index_col=0, squeeze=True, dtype={1: float})
 
     # make sure time index is properly formatted
     y.index = pd.PeriodIndex(y.index, freq="M", name="Period")
@@ -817,7 +822,7 @@ def load_PBS_dataset():
     name = "PBS_dataset"
     fname = name + ".csv"
     path = os.path.join(MODULE, DIRNAME, name, fname)
-    y = pd.read_csv(path, index_col=0, squeeze=True, dtype={1: np.float})
+    y = pd.read_csv(path, index_col=0, squeeze=True, dtype={1: float})
 
     # make sure time index is properly formatted
     y.index = pd.PeriodIndex(y.index, freq="M", name="Period")
@@ -847,12 +852,12 @@ def load_macroeconomic():
 
     References
     ----------
-    ..[1] Wrapped via statsmodels:
+    .. [1] Wrapped via statsmodels:
           https://www.statsmodels.org/dev/datasets/generated/macrodata.html
-    ..[2] Data Source: FRED, Federal Reserve Economic Data, Federal Reserve
+    .. [2] Data Source: FRED, Federal Reserve Economic Data, Federal Reserve
           Bank of St. Louis; http://research.stlouisfed.org/fred2/;
           accessed December 15, 2009.
-    ..[3] Data Source: Bureau of Labor Statistics, U.S. Department of Labor;
+    .. [3] Data Source: Bureau of Labor Statistics, U.S. Department of Labor;
           http://www.bls.gov/data/; accessed December 15, 2009.
     """
     y = sm.datasets.macrodata.load_pandas().data
@@ -863,3 +868,38 @@ def load_macroeconomic():
     y = y.drop(columns=["year", "quarter", "time"])
     y.name = "US Macroeconomic Data"
     return y
+
+
+def load_unit_test_tsf():
+    """
+    Load tsf UnitTest dataset.
+
+    Returns
+    -------
+    loaded_data: pd.DataFrame
+        The converted dataframe containing the time series.
+    frequency: str
+        The frequency of the dataset.
+    forecast_horizon: int
+        The expected forecast horizon of the dataset.
+    contain_missing_values: bool
+        Whether the dataset contains missing values or not.
+    contain_equal_length: bool
+        Whether the series have equal lengths or not.
+    """
+    path = os.path.join(MODULE, DIRNAME, "UnitTest", "UnitTest_Tsf_Loader.tsf")
+    (
+        loaded_data,
+        frequency,
+        forecast_horizon,
+        contain_missing_values,
+        contain_equal_length,
+    ) = load_tsf_to_dataframe(path)
+
+    return (
+        loaded_data,
+        frequency,
+        forecast_horizon,
+        contain_missing_values,
+        contain_equal_length,
+    )
