@@ -27,12 +27,12 @@ __all__ = [
 from typing import List, Union
 
 import numpy as np
-from deprecated.sphinx import deprecated
 
 from sktime.datatypes._alignment import check_dict_Alignment
 from sktime.datatypes._hierarchical import check_dict_Hierarchical
 from sktime.datatypes._panel import check_dict_Panel
-from sktime.datatypes._registry import mtype_to_scitype
+from sktime.datatypes._proba import check_dict_Proba
+from sktime.datatypes._registry import SCITYPE_LIST, mtype_to_scitype
 from sktime.datatypes._series import check_dict_Series
 from sktime.datatypes._table import check_dict_Table
 
@@ -43,6 +43,11 @@ check_dict.update(check_dict_Panel)
 check_dict.update(check_dict_Hierarchical)
 check_dict.update(check_dict_Alignment)
 check_dict.update(check_dict_Table)
+check_dict.update(check_dict_Proba)
+
+
+# mtypes to exclude
+AMBIGUOUS_MTYPES = ["numpyflat", "alignment_loc"]
 
 
 def _check_scitype_valid(scitype: str = None):
@@ -63,81 +68,6 @@ def _ret(valid, msg, metadata, return_metadata):
         return valid
 
 
-#  TODO: remove in v0.11.0
-@deprecated(
-    version="v0.10.0",
-    reason=(
-        "check_is is deprecated since v0.10.0 and will be removed in v0.11.0."
-        "Please use check_is_mtype instead."
-    ),
-    category=FutureWarning,
-)
-def check_is(
-    obj,
-    mtype: Union[str, List[str]],
-    scitype: str = None,
-    return_metadata=False,
-    var_name="obj",
-):
-    """Check object for compliance with mtype specification, return metadata.
-
-    Parameters
-    ----------
-    obj - object to check
-    mtype: str or list of str, mtype to check obj as
-    scitype: str, optional, scitype to check obj as; default = inferred from mtype
-        if inferred from mtype, list elements of mtype need not have same scitype
-    return_metadata - bool, optional, default=False
-        if False, returns only "valid" return
-        if True, returns all three return objects
-    var_name: str, optional, default="obj" - name of input in error messages
-
-    Returns
-    -------
-    valid: bool - whether obj is a valid object of mtype/scitype
-    msg: str or list of str - error messages if object is not valid, otherwise None
-            str if mtype is str; list of len(mtype) with message per mtype if list
-            returned only if return_metadata is True
-    metadata: dict - metadata about obj if valid, otherwise None
-            returned only if return_metadata is True
-        Keys populated depend on (assumed, otherwise identified) scitype of obj.
-        Always returned:
-            "mtype": str, mtype of obj (assumed or inferred)
-            "scitype": str, scitype of obj (assumed or inferred)
-        For scitype "Series":
-            "is_univariate": bool, True iff series has one variable
-            "is_equally_spaced": bool, True iff series index is equally spaced
-            "is_empty": bool, True iff series has no variables or no instances
-            "has_nans": bool, True iff the series contains NaN values
-        For scitype "Panel":
-            "is_univariate": bool, True iff all series in panel have one variable
-            "is_equally_spaced": bool, True iff all series indices are equally spaced
-            "is_equal_length": bool, True iff all series in panel are of equal length
-            "is_empty": bool, True iff one or more of the series in the panel are empty
-            "is_one_series": bool, True iff there is only one series in the panel
-            "has_nans": bool, True iff the panel contains NaN values
-            "n_instances": int, number of instances in the panel
-        For scitype "Table":
-            "is_univariate": bool, True iff table has one variable
-            "is_empty": bool, True iff table has no variables or no instances
-            "has_nans": bool, True iff the panel contains NaN values
-        For scitype "Alignment":
-            currently none
-
-    Raises
-    ------
-    TypeError if no checks defined for mtype/scitype combination
-    TypeError if mtype input argument is not of expected type
-    """
-    return check_is_mtype(
-        obj=obj,
-        mtype=mtype,
-        scitype=scitype,
-        return_metadata=return_metadata,
-        var_name=var_name,
-    )
-
-
 def _coerce_list_of_str(obj, var_name="obj"):
     """Check whether object is string or list of string.
 
@@ -324,18 +254,24 @@ def check_raise(obj, mtype: str, scitype: str = None, var_name: str = "input"):
         raise TypeError(msg)
 
 
-def mtype(obj, as_scitype: Union[str, List[str]] = None):
+def mtype(
+    obj,
+    as_scitype: Union[str, List[str]] = None,
+    exclude_mtypes=AMBIGUOUS_MTYPES,
+):
     """Infer the mtype of an object considered as a specific scitype.
 
     Parameters
     ----------
-    obj : object to infer type of - any type, should comply with and mtype spec
+    obj : object to infer type of - any type, should comply with some mtype spec
         if as_scitype is provided, this needs to be mtype belonging to scitype
     as_scitype : str, list of str, or None, optional, default=None
         name of scitype(s) the object "obj" is considered as, finds mtype for that
         if None (default), does not assume a specific as_scitype and tests all mtypes
             generally, as_scitype should be provided for maximum efficiency
         valid scitype type strings are in datatypes.SCITYPE_REGISTER (1st column)
+    exclude_mtypes : list of str, default = AMBIGUOUS_MTYPES
+        which mtypes to ignore in inferring mtype, default = ambiguous ones
 
     Returns
     -------
@@ -355,12 +291,12 @@ def mtype(obj, as_scitype: Union[str, List[str]] = None):
         for scitype in as_scitype:
             _check_scitype_valid(scitype)
 
-    if as_scitype is None:
-        m_plus_scitypes = [(x[0], x[1]) for x in check_dict.keys()]
-    else:
-        m_plus_scitypes = [
-            (x[0], x[1]) for x in check_dict.keys() if x[1] in as_scitype
-        ]
+    m_plus_scitypes = [
+        (x[0], x[1]) for x in check_dict.keys() if x[0] not in exclude_mtypes
+    ]
+
+    if as_scitype is not None:
+        m_plus_scitypes = [(x[0], x[1]) for x in m_plus_scitypes if x[1] in as_scitype]
 
     res = [
         m_plus_scitype[0]
@@ -384,8 +320,9 @@ def check_is_scitype(
     scitype: Union[str, List[str]],
     return_metadata=False,
     var_name="obj",
+    exclude_mtypes=AMBIGUOUS_MTYPES,
 ):
-    """Check object for compliance with mtype specification, return metadata.
+    """Check object for compliance with scitype specification, return metadata.
 
     Parameters
     ----------
@@ -396,6 +333,8 @@ def check_is_scitype(
         if False, returns only "valid" return
         if True, returns all three return objects
     var_name: str, optional, default="obj" - name of input in error messages
+    exclude_mtypes : list of str, default = AMBIGUOUS_MTYPES
+        which mtypes to ignore in inferring mtype, default = ambiguous ones
 
     Returns
     -------
@@ -442,7 +381,7 @@ def check_is_scitype(
     valid_keys = check_dict.keys()
 
     # find all the mtype keys corresponding to the scitypes
-    keys = [x for x in valid_keys if x[1] in scitype]
+    keys = [x for x in valid_keys if x[1] in scitype and x[0] not in exclude_mtypes]
 
     # storing the msg retursn
     msg = []
@@ -487,3 +426,37 @@ def check_is_scitype(
             msg = msg[0]
 
         return _ret(False, msg, None, return_metadata)
+
+
+def scitype(obj, candidate_scitypes=SCITYPE_LIST, exclude_mtypes=AMBIGUOUS_MTYPES):
+    """Infer the scitype of an object.
+
+    Parameters
+    ----------
+    obj : object to infer type of - any type, should comply with some mtype spec
+        if as_scitype is provided, this needs to be mtype belonging to scitype
+    candidate_scitypes: str or list of str, scitypes to pick from
+        valid scitype strings are in datatypes.SCITYPE_REGISTER
+    exclude_mtypes : list of str, default = AMBIGUOUS_MTYPES
+        which mtypes to ignore in inferring mtype, default = ambiguous ones
+        valid mtype strings are in datatypes.MTYPE_REGISTER
+
+    Returns
+    -------
+    str - the inferred sciype of "obj", a valid scitype string
+            or None, if obj is None
+        scitype strings with explanation are in datatypes.SCITYPE_REGISTER
+
+    Raises
+    ------
+    TypeError if no type can be identified, or more than one type is identified
+    """
+    _, _, metadata = check_is_scitype(
+        obj,
+        scitype=candidate_scitypes,
+        return_metadata=True,
+        exclude_mtypes=exclude_mtypes,
+    )
+    scitype = metadata["scitype"]
+
+    return scitype
