@@ -588,9 +588,12 @@ def from_multi_index_to_3d_numpy(X, instance_index=None, time_index=None):
     X : pd.DataFrame
         The multi-index pandas DataFrame
 
+    instance_index, time_index are deprecated since 0.11.0 and will be removed in 0.12.0
+        these are not necessary, since: as of before 0.11.0, the column names are
+            guaranteed if the mtype is pd-multiindex, and after 0.12.0 the condition
+            on column names is relaxed
     instance_index : str
         Name of the multi-index level corresponding to the DataFrame's instances
-
     time_index : str
         Name of multi-index level corresponding to DataFrame's timepoints
 
@@ -602,23 +605,8 @@ def from_multi_index_to_3d_numpy(X, instance_index=None, time_index=None):
     if X.index.nlevels != 2:
         raise ValueError("Multi-index DataFrame should have 2 levels.")
 
-    if (instance_index is None) or (time_index is None):
-        msg = "Must supply parameters instance_index and time_index"
-        raise ValueError(msg)
-
-    n_instances = len(X.groupby(level=instance_index))
-    # Alternative approach is more verbose
-    # n_instances = (multi_ind_dataframe
-    #                    .index
-    #                    .get_level_values(instance_index)
-    #                    .unique()).shape[0]
-    n_timepoints = len(X.groupby(level=time_index))
-    # Alternative approach is more verbose
-    # n_instances = (multi_ind_dataframe
-    #                    .index
-    #                    .get_level_values(time_index)
-    #                    .unique()).shape[0]
-
+    n_instances = len(X.index.get_level_values(0).unique())
+    n_timepoints = len(X.index.get_level_values(1).unique())
     n_columns = X.shape[1]
 
     X_3d = X.values.reshape(n_instances, n_timepoints, n_columns).swapaxes(1, 2)
@@ -628,9 +616,11 @@ def from_multi_index_to_3d_numpy(X, instance_index=None, time_index=None):
 
 def from_multi_index_to_3d_numpy_adp(obj, store=None):
 
-    return from_multi_index_to_3d_numpy(
-        X=obj, instance_index="instances", time_index="timepoints"
-    )
+    res = from_multi_index_to_3d_numpy(X=obj)
+    if isinstance(store, dict):
+        store["columns"] = obj.columns
+
+    return res
 
 
 convert_dict[("pd-multiindex", "numpy3D", "Panel")] = from_multi_index_to_3d_numpy_adp
@@ -700,8 +690,14 @@ def from_3d_numpy_to_multi_index(
 
 
 def from_3d_numpy_to_multi_index_adp(obj, store=None):
-
-    return from_3d_numpy_to_multi_index(X=obj)
+    res = from_3d_numpy_to_multi_index(X=obj)
+    if (
+        isinstance(store, dict)
+        and "columns" in store.keys()
+        and len(store["columns"]) == obj.shape[1]
+    ):
+        res.columns = store["columns"]
+    return res
 
 
 convert_dict[("numpy3D", "pd-multiindex", "Panel")] = from_3d_numpy_to_multi_index_adp
@@ -730,7 +726,7 @@ def from_multi_index_to_nested(
         The nested version of the DataFrame
     """
     if instance_index is None:
-        raise ValueError("Supply a value for the instance_index parameter.")
+        instance_index = 0
 
     # get number of distinct cases (note: a case may have 1 or many dimensions)
     instance_idxs = multi_ind_dataframe.index.get_level_values(instance_index).unique()
@@ -830,7 +826,8 @@ def from_nested_to_multi_index(X, instance_index=None, time_index=None):
         series = [i[1] for i in X.loc[iidx, :].iteritems()]
         colnames = [i[0] for i in X.loc[iidx, :].iteritems()]
         for x in series:
-            x.name = None
+            if hasattr(x, "name"):
+                x.name = None
 
         instance = [pd.DataFrame(s, columns=[c]) for s, c in zip(series, colnames)]
         instance = pd.concat(instance, axis=1)
@@ -1029,7 +1026,7 @@ def from_dflist_to_numpy3D(obj, store=None):
 convert_dict[("df-list", "numpy3D", "Panel")] = from_dflist_to_numpy3D
 
 
-def from_numpy3D_to_dflist(obj, store=None):
+def from_numpy3d_to_dflist(obj, store=None):
 
     if not isinstance(obj, np.ndarray) or len(obj.shape) != 3:
         raise TypeError("obj must be a 3D numpy.ndarray")
@@ -1040,7 +1037,7 @@ def from_numpy3D_to_dflist(obj, store=None):
     return Xlist
 
 
-convert_dict[("numpy3D", "df-list", "Panel")] = from_numpy3D_to_dflist
+convert_dict[("numpy3D", "df-list", "Panel")] = from_numpy3d_to_dflist
 
 
 def from_nested_to_df_list_adp(obj, store=None):
@@ -1061,3 +1058,72 @@ def from_df_list_to_nested_adp(obj, store=None):
 
 
 convert_dict[("df-list", "nested_univ", "Panel")] = from_df_list_to_nested_adp
+
+
+def from_numpy3d_to_numpyflat(obj, store=None):
+
+    if not isinstance(obj, np.ndarray) or len(obj.shape) != 3:
+        raise TypeError("obj must be a 3D numpy.ndarray")
+
+    shape = obj.shape
+
+    # store second dimension shape/length if we want to restore
+    if isinstance(store, dict):
+        store["numpy_second_dim"] = shape[1]
+
+    obj_in_2D = obj.reshape(shape[0], shape[1] * shape[2])
+
+    return obj_in_2D
+
+
+convert_dict[("numpy3D", "numpyflat", "Panel")] = from_numpy3d_to_numpyflat
+
+
+def from_numpyflat_to_numpy3d(obj, store=None):
+
+    if not isinstance(obj, np.ndarray) or len(obj.shape) != 2:
+        raise TypeError("obj must be a 2D numpy.ndarray")
+
+    shape = obj.shape
+
+    # if store has old 2nd dimension, try to restore, otherwise assume 1
+    if (
+        isinstance(store, dict)
+        and "numpy_second_dim" in store.keys()
+        and isinstance(store["numpy_second_dim"], int)
+        and shape[1] % store["numpy_second_dim"] == 0
+    ):
+        shape_1 = store["numpy_second_dim"]
+        target_shape = (shape[0], shape_1, shape[1] / shape_1)
+    else:
+        target_shape = (shape[0], 1, shape[1])
+
+    obj_in_3D = obj.reshape(target_shape)
+
+    return obj_in_3D
+
+
+convert_dict[("numpyflat", "numpy3D", "Panel")] = from_numpyflat_to_numpy3d
+
+
+# obtain other conversions from/to numpyflat via concatenation to numpy3D
+def _concat(fun1, fun2):
+    def concat_fun(obj, store=None):
+        obj1 = fun1(obj, store=store)
+        obj2 = fun2(obj1, store=store)
+        return obj2
+
+    return concat_fun
+
+
+for tp in set(MTYPE_LIST_PANEL).difference(["numpyflat", "numpy3D"]):
+    if ("numpy3D", tp, "Panel") in convert_dict.keys():
+        convert_dict[("numpyflat", tp, "Panel")] = _concat(
+            convert_dict[("numpyflat", "numpy3D", "Panel")],
+            convert_dict[("numpy3D", tp, "Panel")],
+        )
+    if (tp, "numpy3D", "Panel") in convert_dict.keys():
+        convert_dict[(tp, "numpyflat", "Panel")] = _concat(
+            convert_dict[(tp, "numpy3D", "Panel")],
+            convert_dict[("numpy3D", "numpyflat", "Panel")],
+        )
