@@ -17,7 +17,29 @@ warnings.simplefilter("ignore", category=NumbaWarning)
 
 
 class _WdtwDistance(NumbaDistance):
-    """Weighted dynamic time warping (wdtw) distance between two timeseries."""
+    r"""Weighted dynamic time warping (wdtw) distance between two time series.
+
+    Uses DTW with a weighted pairwise distance matrix rather than a window. When
+    creating the distance matrix $M$, a weight penalty  $w_{|i-j|}$ for a warping
+    distance of $|i-j|$ is applied, so that for series a = <a_1, ..., a_m> and
+    b=<b_1,...,b_m>,
+
+    .. math::
+    M_{i,j}=  w(|i-j|) (a_i-b_j)^2.
+    A logistic weight function, proposed in [1] is used, so that a warping of $x$ places
+    imposes a weighting of
+    .. math::
+    w(x)=\frac{w_{max}}{1+e^{-g(x-m/2)}},
+    where $w_{max}$ is an upper bound on the weight (set to 1), $m$ is the series
+    length and $g$ is a parameter that controls the penalty level for larger warpings.
+    The greater $g$ is, the greater the penalty for warping. Once $M$ is found,
+    standard dynamic time warping is applied.
+
+    References
+    ----------
+    ..[1] Jeong, Y., Jeong, M., Omitaomu, O.: Weighted dynamic time warping for time
+    series classification. Pattern Recognition 44, 2231–2240 (2011)
+    """
 
     def _distance_factory(
         self,
@@ -95,7 +117,7 @@ class _WdtwDistance(NumbaDistance):
 def _weighted_cost_matrix(
     x: np.ndarray, y: np.ndarray, bounding_matrix: np.ndarray, g: float
 ):
-    """Compute the wdtw cost matrix between two timeseries.
+    """Compute the wdtw cost matrix between two time series.
 
     Parameters
     ----------
